Crate uxn_tal

Crate uxn_tal 

Re-exports

pub use util::RealRomCache;
pub use util::RealRomEntryResolver;
pub use assembler::Assembler;
pub use error::AssemblerError;
pub use fetch::parse_uxntal_url;
pub use fetch::resolver::resolve_entry_from_url;
pub use protocol_parser::ProtocolParser;

Modules

assembler
Main assembler implementation
bkend
bkend_buxn
bkend_drif
bkend_uxn
bkend_uxn38
chocolatal
consts
debug
devicemap
Device map parsing and representation for TAL
dis_uxndis
emu_buxn
emu_cuxn
emu_uxn
emulator_utils
error
fetch
hexrev
lexer
Lexer for TAL assembly language
mode_basic
mode_orca
opcode_table
UXN Opcode Reference Table
opcodes
UXN opcodes and instruction definitions
parser
Parser for TAL assembly language
paths
probe_runtime
Probes runtime behavior of a TAL/UXN ROM via dry run or simulation.
probe_tal
protocol_parser
rom
ROM file generation and management
runes
util
v1
wsl

Structs

ProtocolParseResult
Result of protocol parsing
ProtocolQueryVar
ProtocolVar
RepoRef
TalHeuristics
Trait for launching an emulator with the correct command and arguments Heuristics results from TAL source analysis

Enums

EmulatorKind
Enum of all supported emulator mappers for docgen/compatibility table
ProtocolQueryType
ProtocolQueryVarVar
ProtocolVarType
ProtocolVarVar

Statics

BANG_VARS
PROTOCOL_VARS

Traits

EmulatorArgMapper
Emulator argument mapping trait
EmulatorLauncher
EmulatorPathCheck
EmulatorMapperFactory: returns the correct EmulatorArgMapper for a ProtocolParseResult Trait for checking if an emulator binary is available in PATH

Functions

all_emulator_kinds
Returns all supported emulator kinds (for docgen compatibility table)
assemble
assemble_directory
Convenience function to batch process TAL files in a directory
assemble_file
Convenience function to assemble a TAL file directly from a file path
assemble_file_auto
Convenience function to assemble a TAL file and save ROM with same name but .rom extension
assemble_file_to_rom
Convenience function to assemble a TAL file and save the ROM to a file
assemble_file_with_symbols
Convenience function to assemble a TAL file and generate both ROM and symbol files
assemble_with_path
assemble_with_rust_interface_module
emulator_kind_name
Returns the display name for an emulator kind
generate_rust_interface_module
get_emulator_launcher
EmulatorMapperFactory: returns the correct EmulatorArgMapper and path for a ProtocolParseResult
get_emulator_launcher_with_heuristics
Get emulator launcher with heuristics-based CLI selection If heuristics indicate console-only usage and the emulator supports CLI, use CLI version
get_emulator_mapper
EmulatorMapperFactory: returns the correct EmulatorArgMapper for a ProtocolParseResult
get_or_write_cached_rom
Stub only: the real implementation must be provided in the application crate (uxn-tal).
hash_url
Non-cryptographic, stable hash for cache bucketing.
percent_decode_or_original
Decode percent-encoding. If the decoded bytes aren’t valid UTF-8, return the original string unchanged.