Re-exports
pub use util::RealRomCache;pub use util::RealRomEntryResolver;pub use assembler::Assembler;pub use error::AssemblerError;pub use fetch::parse_uxntal_url;pub use fetch::resolver::resolve_entry_from_url;pub use protocol_parser::ProtocolParser;
Modules
- assembler
- Main assembler implementation
- bkend
- bkend_
buxn - bkend_
drif - bkend_
uxn - bkend_
uxn38 - chocolatal
- consts
- debug
- devicemap
- Device map parsing and representation for TAL
- dis_
uxndis - emu_
buxn - emu_
cuxn - emu_uxn
- emulator_
utils - error
- fetch
- hexrev
- lexer
- Lexer for TAL assembly language
- mode_
basic - mode_
orca - opcode_
table - UXN Opcode Reference Table
- opcodes
- UXN opcodes and instruction definitions
- parser
- Parser for TAL assembly language
- paths
- probe_
runtime - Probes runtime behavior of a TAL/UXN ROM via dry run or simulation.
- probe_
tal - protocol_
parser - rom
- ROM file generation and management
- runes
- util
- v1
- wsl
Structs
- Protocol
Parse Result - Result of protocol parsing
- Protocol
Query Var - Protocol
Var - RepoRef
- TalHeuristics
- Trait for launching an emulator with the correct command and arguments Heuristics results from TAL source analysis
Enums
- Emulator
Kind - Enum of all supported emulator mappers for docgen/compatibility table
- Protocol
Query Type - Protocol
Query VarVar - Protocol
VarType - Protocol
VarVar
Statics
Traits
- Emulator
ArgMapper - Emulator argument mapping trait
- Emulator
Launcher - Emulator
Path Check - EmulatorMapperFactory: returns the correct EmulatorArgMapper for a ProtocolParseResult Trait for checking if an emulator binary is available in PATH
Functions
- all_
emulator_ kinds - Returns all supported emulator kinds (for docgen compatibility table)
- assemble
- assemble_
directory - Convenience function to batch process TAL files in a directory
- assemble_
file - Convenience function to assemble a TAL file directly from a file path
- assemble_
file_ auto - Convenience function to assemble a TAL file and save ROM with same name but .rom extension
- assemble_
file_ to_ rom - Convenience function to assemble a TAL file and save the ROM to a file
- assemble_
file_ with_ symbols - Convenience function to assemble a TAL file and generate both ROM and symbol files
- assemble_
with_ path - assemble_
with_ rust_ interface_ module - emulator_
kind_ name - Returns the display name for an emulator kind
- generate_
rust_ interface_ module - get_
emulator_ launcher - EmulatorMapperFactory: returns the correct EmulatorArgMapper and path for a ProtocolParseResult
- get_
emulator_ launcher_ with_ heuristics - Get emulator launcher with heuristics-based CLI selection If heuristics indicate console-only usage and the emulator supports CLI, use CLI version
- get_
emulator_ mapper - EmulatorMapperFactory: returns the correct EmulatorArgMapper for a ProtocolParseResult
- get_
or_ write_ cached_ rom - Stub only: the real implementation must be provided in the application crate (uxn-tal).
- hash_
url - Non-cryptographic, stable hash for cache bucketing.
- percent_
decode_ or_ original - Decode percent-encoding. If the decoded bytes aren’t valid UTF-8, return the original string unchanged.